==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GremlinGraphResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Cosmos DB Gremlin graph resource object
 * @property analyticalStorageTtl Analytical TTL.
 * @property conflictResolutionPolicy The conflict resolution policy for the graph.
 * @property defaultTtl Default time to live
 * @property id Name of the Cosmos DB Gremlin graph
 * @property indexingPolicy The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
 * @property partitionKey The configuration of the partition key to be used for partitioning data into multiple partitions
 * @property uniqueKeyPolicy The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 */
public data class GremlinGraphResourceArgs(
    public val analyticalStorageTtl: Output<Double>? = null,
    public val conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null,
    public val defaultTtl: Output<Int>? = null,
    public val id: Output<String>,
    public val indexingPolicy: Output<IndexingPolicyArgs>? = null,
    public val partitionKey: Output<ContainerPartitionKeyArgs>? = null,
    public val uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder()
            .analyticalStorageTtl(analyticalStorageTtl?.applyValue({ args0 -> args0 }))
            .conflictResolutionPolicy(
                conflictResolutionPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .defaultTtl(defaultTtl?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .indexingPolicy(indexingPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uniqueKeyPolicy(
                uniqueKeyPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GremlinGraphResourceArgs].
 */
@PulumiTagMarker
public class GremlinGraphResourceArgsBuilder internal constructor() {
    private var analyticalStorageTtl: Output<Double>? = null

    private var conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null

    private var defaultTtl: Output<Int>? = null

    private var id: Output<String>? = null

    private var indexingPolicy: Output<IndexingPolicyArgs>? = null

    private var partitionKey: Output<ContainerPartitionKeyArgs>? = null

    private var uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null

    /**
     * @param value Analytical TTL.
     */
    @JvmName("hbahpexrkmlqcogc")
    public suspend fun analyticalStorageTtl(`value`: Output<Double>) {
        this.analyticalStorageTtl = value
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("qymqqadotjjvpqaw")
    public suspend fun conflictResolutionPolicy(`value`: Output<ConflictResolutionPolicyArgs>) {
        this.conflictResolutionPolicy = value
    }

    /**
     * @param value Default time to live
     */
    @JvmName("nfkfyuonhpyoximx")
    public suspend fun defaultTtl(`value`: Output<Int>) {
        this.defaultTtl = value
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("naaaqdkjfkrqimtv")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("pminemyfomcbegad")
    public suspend fun indexingPolicy(`value`: Output<IndexingPolicyArgs>) {
        this.indexingPolicy = value
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("uyqoevwockxontpj")
    public suspend fun partitionKey(`value`: Output<ContainerPartitionKeyArgs>) {
        this.partitionKey = value
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("kgvlxvdlcqjifflm")
    public suspend fun uniqueKeyPolicy(`value`: Output<UniqueKeyPolicyArgs>) {
        this.uniqueKeyPolicy = value
    }

    /**
     * @param value Analytical TTL.
     */
    @JvmName("tjaqpbfhcgsmmrhk")
    public suspend fun analyticalStorageTtl(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.analyticalStorageTtl = mapped
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("qbxcapcwdnhmyerj")
    public suspend fun conflictResolutionPolicy(`value`: ConflictResolutionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param argument The conflict resolution policy for the graph.
     */
    @JvmName("emhkhryqxqthqsko")
    public suspend
    fun conflictResolutionPolicy(argument: suspend ConflictResolutionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ConflictResolutionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param value Default time to live
     */
    @JvmName("ytippwuptwgkodxo")
    public suspend fun defaultTtl(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultTtl = mapped
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("ktymkpnkisdavadl")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("bcahindhuxxfnlrd")
    public suspend fun indexingPolicy(`value`: IndexingPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexingPolicy = mapped
    }

    /**
     * @param argument The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("ucoucxdebfvyuqxd")
    public suspend fun indexingPolicy(argument: suspend IndexingPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = IndexingPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.indexingPolicy = mapped
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("bykdofwadoniqeqa")
    public suspend fun partitionKey(`value`: ContainerPartitionKeyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param argument The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("gcyntfdtididimqf")
    public suspend fun partitionKey(argument: suspend ContainerPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerPartitionKeyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.partitionKey = mapped
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("iiegttjeslcpgulw")
    public suspend fun uniqueKeyPolicy(`value`: UniqueKeyPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeyPolicy = mapped
    }

    /**
     * @param argument The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("rbikhdwdtnrxdtlg")
    public suspend fun uniqueKeyPolicy(argument: suspend UniqueKeyPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = UniqueKeyPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.uniqueKeyPolicy = mapped
    }

    internal fun build(): GremlinGraphResourceArgs = GremlinGraphResourceArgs(
        analyticalStorageTtl = analyticalStorageTtl,
        conflictResolutionPolicy = conflictResolutionPolicy,
        defaultTtl = defaultTtl,
        id = id ?: throw PulumiNullFieldException("id"),
        indexingPolicy = indexingPolicy,
        partitionKey = partitionKey,
        uniqueKeyPolicy = uniqueKeyPolicy,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GremlinGraphResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Cosmos DB Gremlin graph resource object
 * @property analyticalStorageTtl Analytical TTL.
 * @property conflictResolutionPolicy The conflict resolution policy for the graph.
 * @property defaultTtl Default time to live
 * @property id Name of the Cosmos DB Gremlin graph
 * @property indexingPolicy The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
 * @property partitionKey The configuration of the partition key to be used for partitioning data into multiple partitions
 * @property uniqueKeyPolicy The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 */
public data class GremlinGraphResourceArgs(
    public val analyticalStorageTtl: Output<Double>? = null,
    public val conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null,
    public val defaultTtl: Output<Int>? = null,
    public val id: Output<String>,
    public val indexingPolicy: Output<IndexingPolicyArgs>? = null,
    public val partitionKey: Output<ContainerPartitionKeyArgs>? = null,
    public val uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder()
            .analyticalStorageTtl(analyticalStorageTtl?.applyValue({ args0 -> args0 }))
            .conflictResolutionPolicy(
                conflictResolutionPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .defaultTtl(defaultTtl?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .indexingPolicy(indexingPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uniqueKeyPolicy(
                uniqueKeyPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GremlinGraphResourceArgs].
 */
@PulumiTagMarker
public class GremlinGraphResourceArgsBuilder internal constructor() {
    private var analyticalStorageTtl: Output<Double>? = null

    private var conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null

    private var defaultTtl: Output<Int>? = null

    private var id: Output<String>? = null

    private var indexingPolicy: Output<IndexingPolicyArgs>? = null

    private var partitionKey: Output<ContainerPartitionKeyArgs>? = null

    private var uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null

    /**
     * @param value Analytical TTL.
     */
    @JvmName("ibffohrsirvprsgx")
    public suspend fun analyticalStorageTtl(`value`: Output<Double>) {
        this.analyticalStorageTtl = value
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("rvfysaqnujkiduis")
    public suspend fun conflictResolutionPolicy(`value`: Output<ConflictResolutionPolicyArgs>) {
        this.conflictResolutionPolicy = value
    }

    /**
     * @param value Default time to live
     */
    @JvmName("rxustgakdojalmfe")
    public suspend fun defaultTtl(`value`: Output<Int>) {
        this.defaultTtl = value
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("iymmlirlcgelrxvk")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("ebmsirmqrlpfkxvx")
    public suspend fun indexingPolicy(`value`: Output<IndexingPolicyArgs>) {
        this.indexingPolicy = value
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("dankyqycmjrnfsqc")
    public suspend fun partitionKey(`value`: Output<ContainerPartitionKeyArgs>) {
        this.partitionKey = value
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("jelwyjqfqqsxtklk")
    public suspend fun uniqueKeyPolicy(`value`: Output<UniqueKeyPolicyArgs>) {
        this.uniqueKeyPolicy = value
    }

    /**
     * @param value Analytical TTL.
     */
    @JvmName("anabagfgcqtblxcs")
    public suspend fun analyticalStorageTtl(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.analyticalStorageTtl = mapped
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("uptudpyqfwddytth")
    public suspend fun conflictResolutionPolicy(`value`: ConflictResolutionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param argument The conflict resolution policy for the graph.
     */
    @JvmName("mvmkkfxthrsfepiu")
    public suspend
    fun conflictResolutionPolicy(argument: suspend ConflictResolutionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ConflictResolutionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param value Default time to live
     */
    @JvmName("rdxdxmlfivunrjbh")
    public suspend fun defaultTtl(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultTtl = mapped
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("kfvqnflnqqcypveg")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("rroksglxfhhkmhjs")
    public suspend fun indexingPolicy(`value`: IndexingPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexingPolicy = mapped
    }

    /**
     * @param argument The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("nqnnslcvhmxeosvi")
    public suspend fun indexingPolicy(argument: suspend IndexingPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = IndexingPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.indexingPolicy = mapped
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("yosmbjskvyfkgtgi")
    public suspend fun partitionKey(`value`: ContainerPartitionKeyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param argument The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("cvictwxdhqcgaqfe")
    public suspend fun partitionKey(argument: suspend ContainerPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerPartitionKeyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.partitionKey = mapped
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("waoqlamyafuyrvfp")
    public suspend fun uniqueKeyPolicy(`value`: UniqueKeyPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeyPolicy = mapped
    }

    /**
     * @param argument The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("rndwigxjkyfoxxgd")
    public suspend fun uniqueKeyPolicy(argument: suspend UniqueKeyPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = UniqueKeyPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.uniqueKeyPolicy = mapped
    }

    internal fun build(): GremlinGraphResourceArgs = GremlinGraphResourceArgs(
        analyticalStorageTtl = analyticalStorageTtl,
        conflictResolutionPolicy = conflictResolutionPolicy,
        defaultTtl = defaultTtl,
        id = id ?: throw PulumiNullFieldException("id"),
        indexingPolicy = indexingPolicy,
        partitionKey = partitionKey,
        uniqueKeyPolicy = uniqueKeyPolicy,
    )
}
